import { getPhonePrefix } from '../../api/user'
import { getStorageSync, showToast, setStorageSync, navigateBack } from '../../utils/util'

Page({

  /**
   * 页面的初始数据
   */
  data: {
    areaData: [],
    selectId: 0
  },

  /**
   * 生命周期函数--监听页面加载
   */
  onLoad: function (options) {
    const prefixArr = getStorageSync('MOBILEPREFIXDATA')
    if (prefixArr) {
      this.setData({
        areaData: prefixArr
      })
    } else {
      this.loadPrefix()
    }

    if (options.id) {
      this.setData({
        selectId: options.id
      })
    }

    if (options.name) {
      wx.setNavigationBarTitle({
        title: options.name,
      })
    }
  },

  loadPrefix: function () {
    const params = {
      range: 'B',
      prefix: '1'
    }
    getPhonePrefix(params).then((result) => {
      const data = result.data
      if (!Array.isArray(data) || data.length === 0) {
        showToast({ title: '网络不稳定，请重新操作' })
        return
      }
      // 二维转一维数组
      const prefixArr = data.reduce((res, cur) => {
        return res.concat(cur.list)
      }, [])

      this.setData({
        areaData: prefixArr,
        isLoading: false
      })
      setStorageSync('MOBILEPREFIXDATA', prefixArr)
    }).catch((err) => {
      showToast({ title: '网络不稳定，请重新操作' })
    })
  },

  tapAction(e) {
    const { currentIndex } = e.currentTarget.dataset
    let pages = getCurrentPages() /*在内存中的所有页面栈对象*/
    let prePage = pages[pages.length - 2] /*我的页面对象*/
    if (prePage) {
      const data = this.data.areaData[currentIndex]
      if (prePage.areaCodeCallback) prePage.areaCodeCallback({
        prefixIndex: currentIndex,
        areaData: data
      })
      navigateBack()
    } else {
      navigateBack()
    }
  }
})
