// pages/detail/detail.js
import { getGroupDetailNew } from '../../api/index'
import { getStorageSync, reLaunch } from '../../utils/util'

Page({
  /**
   * 页面的初始数据
   */
  data: {
    detailId: '',
    loading: true,
    showBackBtn: false,
    userInfo: null,
    hasUserInfo: false,
    hideJoinTip: true,
    detail: null,
    dialogStatus: false
  },

  /**
   * 生命周期函数--监听页面加载
   */
  onLoad: function (options) {
    this.data.detailId = options.id
    this.getDetail()
  },

  onShow: function () {
    // 从分享进入，栈中只有当前页
    const curPages = getCurrentPages()
    const showBackBtn = curPages.length === 1

    const userInfo = getStorageSync('USERINFO')
    if (userInfo) {
      this.setData({
        showBackBtn,
        userInfo: userInfo,
        hasUserInfo: true
      })
    } else {
      this.setData({
        showBackBtn,
        hasUserInfo: false
      })
    }
  },

  /**
   * 用户点击右上角分享
   */
  onShareAppMessage: function () {
    const title =  this.data.detail.shareContent || '组织已准备好，还不快来~'
    const id = this.data.detailId
    return {
      title,
      path: `/pages/detail/detail?id=${id}`
    }
  },

  // 获取群详情
  getDetail() {
    const id = this.data.detailId
    getGroupDetailNew({ id }).then((result) => {
      const detail = result.data
      // 文本域内容换行
      if(detail.content) {
        detail.content = detail.content.split('\n')
      }
      this.setData({
        loading: false,
        detail,
        hideJoinTip: false
      })
      // 数秒后tip消失
      setTimeout(() => {
        this.setData({
          hideJoinTip: true
        })
      }, 2000)
    }).catch((err) => {
      setTimeout(() => {
        reLaunch('/pages/index/index')
      }, 500)
    })
  },

  // 截图预览
  showPreview: function (e) {
    const { index } = e.currentTarget.dataset
    const imgs = this.data.detail.imgsUrl
    wx.previewImage({
      current: imgs[index], // 当前显示图片的http链接
      urls: imgs // 需要预览的图片http链接列表
    })
  },

  // 取消分享
  onCancel: function () {
    this.setData({
      dialogStatus: false
    })
  },

  // 点击分享回调
  onConfirm: function () {
    this.setData({
      dialogStatus: false
    })
  },

  backHome: function () {
    reLaunch('/pages/index/index')
  },

  startmessage: function(res) {
    // if (!this.data.hasUserInfo) {
    //   return navigateTo('/pages/login/login')
    // }
  },
  
  completemessage: function(res) {
    if(res.detail.errcode === 0) {
      this.setData({
        dialogStatus: true
      })
    }
  }
})
